@@ -6,9 +6,8 @@
 #' 
 #' @name remote-package
 #' @aliases remote
-#' @docType package
 #' @title R EMpirical Orthogonal TEleconnections
-#' @author Tim Appelhans, Florian Detsch\cr
+#' @author Tim Appelhans, Florian Detsch, Thomas Nauss\cr
 #' \cr
 #' \emph{Maintainer:} Tim Appelhans \email{tim.appelhans@@gmail.com}
 #' 
@@ -21,15 +20,16 @@
 #' Empirical methods in short-term climate prediction\cr
 #' H. M. van den Dool (2007)\cr
 #' Oxford University Press, Oxford, New York (2007)\cr
-#' @seealso \pkg{remote} is built upon Raster* classes from the \code{\link{raster-package}}.
-#' Please see their documentation for data preparation etc.
-#' @import Rcpp raster gridExtra latticeExtra mapdata scales methods
+#' @seealso \pkg{remote} is built upon Raster* classes from the 
+#' [raster::raster-package]. Please see their documentation for data preparation etc.
+#' @import Rcpp raster gridExtra latticeExtra mapdata scales methods parallel
 #' @importFrom grDevices colorRampPalette hcl 
 #' @importFrom stats pt var cov.wt na.exclude princomp na.omit
-#' @importFrom utils write.table
+#' @importFrom utils read.csv write.table
 #' @useDynLib remote
 #' 
-NULL
+"_PACKAGE"
+
 #' 
 #' @docType data 
 #' @name vdendool
@@ -46,10 +46,9 @@ NULL
 #' The NCEP/NCAR 40-year reanalysis project\cr
 #' Kalnay et al. (1996)\cr
 #' Bulletin of the American Meteorological Society, Volume 77, Issue 3, pp 437 - 471\cr
-#' \url{http://journals.ametsoc.org/doi/abs/10.1175/1520-0477(1996)077%3C0437%3ATNYRP%3E2.0.CO%3B2
-#' }
+#' \doi{10.1175/1520-0477(1996)077<0437:TNYRP>2.0.CO;2}
 #' @source
-#' \url{http://www.esrl.noaa.gov/psd/data/gridded/data.ncep.reanalysis.derived.pressure.html}\cr
+#' <https://psl.noaa.gov/data/gridded/data.ncep.reanalysis.derived.pressure.html>\cr
 #' \emph{Original Source:} NOAA National Center for Environmental Prediction
 NULL
 #' 
@@ -70,7 +69,7 @@ NULL
 #' The Version-2 Global Precipitation Climatology Project (GPCP) Monthly Precipitation Analysis (1979 - Present)\cr
 #' Adler et al. (2003)\cr
 #' Journal of Hydrometeorology, Volume 4, Issue 6, pp. 1147 - 1167\cr
-#' \url{http://dx.doi.org/10.1175/1525-7541(2003)004<1147:TVGPCP>2.0.CO;2}
+#' \doi{10.1175/1525-7541(2003)004<1147:TVGPCP>2.0.CO;2}
 NULL
 #' 
 #' @docType data 
@@ -88,5 +87,5 @@ NULL
 #' Daily High-Resolution-Blended Analyses for Sea Surface Temperature\cr
 #' Reynolds et al. (2007)\cr
 #' Journal of Climate, Volume 20, Issue 22, pp. 5473 - 5496\cr
-#' \url{http://dx.doi.org/10.1175/2007JCLI1824.1}
+#' \doi{10.1175/2007JCLI1824.1}
 NULL
